/*
 * game_beast.h
 * 
 * Copyright (C) 2005  Josef Kufner <jk@myserver.cz>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 * 
 */
#ifndef JK_GAME_BEAST_H
#define JK_GAME_BEAST_H

#include "game_object.h"

/*****************************************************************************
 * GBeast -- hejbajici se potvoly
 */
class GBeast : public GObject {
	public:
		GBeast (void);
		void step(void);
		virtual void after_step(void) = 0;
		void turn_left(void) {
			direction = (old_direction + 1) % 4;
		}
		void turn_right(void) {
			direction = (old_direction + 3) % 4;
		}

	protected:
		bool calculate_step(int &new_x, int &new_y, int &new_z);
		enum {
			UP = 0, RIGHT, DOWN, LEFT
		}; 
		int direction;
		int old_direction;
		int speed;		// required steps to move
		int waiting;
		int score;

		GObjectList local_obj;
};

/*****************************************************************************
 * GKrtek -- postavicka krtka
 */
class GKrtek : public GBeast {
	public:
		GKrtek(void) {
			name = "Krtek";
			goid = GOID_KRTEK;
			direction = RIGHT;
			speed = 3;
		};
		GSymbol* draw(void) {
			return new GSymbol('K', 15, pos_x, pos_y, pos_z);
		};
		void after_step(void);
	private:
};


/*****************************************************************************
 * GZahradnik -- postavicka zahradnika
 */
class GZahradnik : public GBeast {
	public:
		GZahradnik(void) {
			name = "Zahradnik";
			goid = GOID_ZAHRADNIK;
			direction = LEFT;
			speed = 2;
			kyticka = 0;
		};
		GSymbol* draw(void) {
			return new GSymbol('Z', 11, pos_x, pos_y, pos_z);
		};
		void after_step(void);
	private:
		int kyticka;
};


#endif
