/*
 * main.cc
 * 
 * Copyright (C) 2005  Josef Kufner <jk@myserver.cz>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 * 
 */

#include <stdio.h>
#include <stdlib.h>
#include <signal.h>
#include <unistd.h>

#include "game.h"
#include "sample.h"
#include "screen.h"

#define DEBUG 0
#include "debug.h"

int done = 0;

Sample *sample = NULL;
Screen *screen = NULL;
Game *game = NULL;


void on_signal(int sig) {
	signal(SIGINT, SIG_DFL);
	game->kill();
	return;
}

void on_term_resize(int sig) {
	if (screen)
		screen->resize_notify();
}



int main (int argc, char *argv[]) {

	sample = new Sample();
	screen = new Screen();
	game   = new Game(screen);
	
	signal(SIGINT, on_signal);
	signal(SIGWINCH, on_term_resize);

	/* connect game--sample */
	game->connect_to_pipe(sample->get_pipe());
	game->main();
	
	delete game;
	delete screen;
	delete sample;
	return EXIT_SUCCESS;
}

