/*
 * screen.h
 * 
 * Copyright (C) 2005  Josef Kufner <jk@myserver.cz>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 * 
 */
#ifndef JK_SCREEN_H
#define JK_SCREEN_H

#include <vector>

#include "game_world.h"
#include "thread.h"

class Screen {
	public:
		Screen(void);
		~Screen(void);

		void set_status(int krtek_key, int krtek_score, int zahradnik_key, int zahradnik_score);
		void render_world(GameWorld *world);
		void render_freq(int *freq, int size, int min_colorized, int intensity, int intensity_min);
		void add_freq(float from, float to, char label);
		void clear_freq_rule(void);
		
		void resize_notify(void);
		void draw_all(void);
		void draw_status(void);
		void draw_world(void);
		void draw_freq(void);
		void redraw(void);
		void flush(void);
	private:
		//void *main (void);
		struct s_freq_label {
			float from, to; 
			char label;
		};
		typedef std::list<s_freq_label> FreqRule;

		int resized;
		std::vector<GSymbol *>symbol;
		int world_height, world_width;
		int screen_height, screen_width;
		int bar_height, bar_width;
		int status[4];
		std::vector<int> freq_bar;
		int freq_bar_max;
		int freq_bar_min_colorized;
		float hscale;

		int intensity, intensity_min;

		FreqRule freq_rule;
};

#endif
